@@ -6,7 +6,7 @@ pop.index.plot<-function(data,xlim1,xlim2,xinc,ylim1,ylim2,yinc)
   year<-year(data$date[1])
   solvals<-seq(xlim1,xlim2,by=xinc)
   dates<-solar.long_date(solvals,paste(year,"-01-01",sep=""),paste(year,"-12-31",sep=""))
-  xlab2<-paste(day(dates),month.abb[month(dates)]," ",strftime(dates,format="%H:%M"),sep="")
+  xlab2<-paste(day(dates),month.abb[month(dates)]," ",strftime(dates,format="%H:%M",tz="UTC"),sep="")
   
   par(mar=c(5,4,6,3))
   graph.data(data$sollong,data$pop.index,data$r.error,"Population index",xlim1,xlim2,xinc,ylim1,ylim2,yinc)
